==> playfunads-3.0.1-sources.jar: playfun/ads/android/sdk/component/model/networkmodel/Data.java <==

package playfun.ads.android.sdk.component.model.networkmodel;

import android.os.Parcel;
import android.os.Parcelable;

import java.util.List;
import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

public class Data implements Parcelable {

    @SerializedName("htmlData")
    @Expose
    private String htmlData;
    @SerializedName("metaData")
    @Expose
    private MetaData metaData;
    @SerializedName("templateType")
    @Expose
    private String templateType;
    @SerializedName("limit")
    @Expose
    private Limit limit;
    @SerializedName("raa_id")
    @Expose
    private Integer raaId;
    @SerializedName("dimension")
    @Expose
    private String dimension;
    @SerializedName("countdown")
    @Expose
    private CountDown countdown;

    public String getHtmlData() {
        return htmlData;
    }

    public void setHtmlData(String htmlData) {
        this.htmlData = htmlData;
    }

    public MetaData getMetaData() {
        return metaData;
    }

    public void setMetaData(MetaData metaData) {
        this.metaData = metaData;
    }

    public String getTemplateType() {
        return templateType;
    }

    public void setTemplateType(String templateType) {
        this.templateType = templateType;
    }
    public Limit getLimit() {
        return limit;
    }

    public void setLimit(Limit limit) {
        this.limit = limit;
    }

    public Integer getRaaId() {
        return raaId;
    }

    public void setRaaId(Integer raaId) {
        this.raaId = raaId;
    }

    public String getDimension() {
        return dimension;
    }

    public void setDimension(String dimension) {
        this.dimension = dimension;
    }

    public CountDown getCountdown() {
        return countdown;
    }

    public void setCountdown(CountDown countdown) {
        this.countdown = countdown;
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public void writeToParcel(Parcel out, int flags) {
        out.writeParcelable(metaData,flags);
        out.writeParcelable(countdown,flags);
        out.writeParcelable(limit,flags);
        out.writeString(htmlData);
        out.writeInt(raaId);
        out.writeString(dimension);
        out.writeString(templateType);
    }

    public static final Parcelable.Creator<Data> CREATOR
            = new Parcelable.Creator<Data>() {
        public Data createFromParcel(Parcel in) {
            return new Data(in);
        }

        public Data[] newArray(int size) {
            return new Data[size];
        }
    };

    private Data(Parcel in) {
        metaData = (MetaData) in.readParcelable(MetaData.class.getClassLoader());
        countdown = (CountDown) in.readParcelable(MetaData.class.getClassLoader());
        limit = (Limit) in.readParcelable(MetaData.class.getClassLoader());
        htmlData = in.readString();
        raaId = in.readInt();
        dimension = in.readString();
    }

}

==> playfunads-3.0.8-sources.jar: playfun/ads/android/sdk/component/model/networkmodel/Data.java <==

package playfun.ads.android.sdk.component.model.networkmodel;

import android.os.Parcel;
import android.os.Parcelable;

import java.util.List;
import com.google.gson.annotations.Expose;
import com.google.gson.annotations.SerializedName;

public class Data implements Parcelable {

    @SerializedName("htmlData")
    @Expose
    private String htmlData;
    @SerializedName("metaData")
    @Expose
    private MetaData metaData;
    @SerializedName("templateType")
    @Expose
    private String templateType;
    @SerializedName("limit")
    @Expose
    private Limit limit;
    @SerializedName("raa_id")
    @Expose
    private Integer raaId;
    @SerializedName("dimension")
    @Expose
    private String dimension;
    @SerializedName("countdown")
    @Expose
    private CountDown countdown;
    @SerializedName("countdown_off")
    @Expose
    private CountdownOff countdownOff;

    public String getHtmlData() {
        return htmlData;
    }

    public void setHtmlData(String htmlData) {
        this.htmlData = htmlData;
    }

    public MetaData getMetaData() {
        return metaData;
    }

    public void setMetaData(MetaData metaData) {
        this.metaData = metaData;
    }

    public String getTemplateType() {
        return templateType;
    }

    public void setTemplateType(String templateType) {
        this.templateType = templateType;
    }
    public Limit getLimit() {
        return limit;
    }

    public void setLimit(Limit limit) {
        this.limit = limit;
    }

    public Integer getRaaId() {
        return raaId;
    }

    public void setRaaId(Integer raaId) {
        this.raaId = raaId;
    }

    public String getDimension() {
        return dimension;
    }

    public void setDimension(String dimension) {
        this.dimension = dimension;
    }

    public CountDown getCountdown() {
        return countdown;
    }

    public void setCountdown(CountDown countdown) {
        this.countdown = countdown;
    }

    public CountdownOff getCountdownOff() {
        return countdownOff;
    }

    public void setCountdownOff(CountdownOff countdownOff) {
        this.countdownOff = countdownOff;
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public void writeToParcel(Parcel out, int flags) {
        out.writeParcelable(metaData,flags);
        out.writeParcelable(countdown,flags);
        out.writeParcelable(limit,flags);
        out.writeString(htmlData);
        out.writeInt(raaId);
        out.writeString(dimension);
        out.writeString(templateType);
    }

    public static final Parcelable.Creator<Data> CREATOR
            = new Parcelable.Creator<Data>() {
        public Data createFromParcel(Parcel in) {
            return new Data(in);
        }

        public Data[] newArray(int size) {
            return new Data[size];
        }
    };

    private Data(Parcel in) {
        metaData = (MetaData) in.readParcelable(MetaData.class.getClassLoader());
        countdown = (CountDown) in.readParcelable(MetaData.class.getClassLoader());
        limit = (Limit) in.readParcelable(MetaData.class.getClassLoader());
        htmlData = in.readString();
        raaId = in.readInt();
        dimension = in.readString();
    }

}
